@@ -5,7 +5,8 @@
 #'
 #' @param hostname A string, e.g. "ec2-34-217-73-26.us-west-2.compute.amazonaws.com".
 #'     Optional, default is "localhost".
-#' @param router A string, e.g. "UK2018". Optional, default is "default".
+#' @param router A string, e.g. "UK2018". Optional, default is "default". Do not
+#' specify for OTPv2 which does not support named routers.
 #' @param port A positive integer. Optional, default is 8080.
 #' @param ssl Logical, indicates whether to use https. Optional, default is FALSE.
 #' @param tz A string, containing the time zone of the router's graph. Optional.
@@ -14,10 +15,8 @@
 #' current system (obtained from \code{Sys.timezone()}). Using the default will
 #' be ok if the current system time zone is the same as the time zone of the OTP
 #' graph.
-#' @param check Logical. If TRUE connection object is only returned if OTP
-#'     instance and router are confirmed reachable. Optional, default is TRUE.
-#' @return Returns S3 object of class otpconnect. If \code{check} is TRUE
-#'     and the router is not reachable the object is not returned.
+#' @param check Deprecated and has no effect.
+#' @return Returns S3 object of class otpconnect if reachable.
 #' @examples \dontrun{
 #' otpcon <- otpr_connect()
 #' otpcon <- otpr_connect(router = "UK2018",
@@ -35,6 +34,11 @@ otp_connect <- function(hostname = "localhost",
                         ssl = FALSE,
                         check = TRUE)
 {
+
+  # the check argument is now deprecated and has no effect
+  if (!missing("check"))
+    warning("argument 'check' has been deprecated and has no effect", call. = FALSE)
+
   # argument checks
 
   coll <- checkmate::makeAssertCollection()
@@ -42,18 +46,17 @@ otp_connect <- function(hostname = "localhost",
   checkmate::assert_string(router, add = coll)
   checkmate::assert_int(port, lower = 1, add = coll)
   checkmate::assert_logical(ssl, add = coll)
-  checkmate::assert_logical(check, add = coll)
   checkmate::reportAssertions(coll)
 
   # Check if tz is a valid timezone
-
   if (isFALSE(checkmate::test_choice(tz, OlsonNames()))) {
     stop("Assertion on 'tz' failed:", " Must be a valid time zone")
   }
 
-
+  # Create the otpcon object
   otpcon <- list(
     hostname = hostname,
+    version = 0,
     router = router,
     port = port,
     tz = tz,
@@ -63,22 +66,38 @@ otp_connect <- function(hostname = "localhost",
   # Set the name for the class
   class(otpcon) <- append(class(otpcon), "otpconnect")
 
-
-  # If check then confirm router is queryable
-
-  if (isTRUE(check)) {
-    if (check_router(otpcon) == 200) {
-      message("Router ", make_url(otpcon), " exists")
-      return(otpcon)
-    } else {
-      stop("Router ", make_url(otpcon),  " does not exist")
-    }
+  # Get OTP version
+  # /otp API endpoint must be enabled on the OTP instance (it is by default)
+  req <- try(httr::GET(make_url(otpcon)$otp), silent = T)
+  if (class(req) == "try-error") {
+    stop("Unable to connect to OTP. Does ",
+         make_url(otpcon)$otp,
+         " even exist?")
+  } else if (req$status_code != 200) {
+    stop("Unable to determine OTP version. Does ",
+         make_url(otpcon)$otp,
+         " even exist?")
   } else {
+    # convert to text
+    req <- httr::content(req, as = "text", encoding = "UTF-8")
+    # parse text to json
+    req <- jsonlite::fromJSON(req, flatten = TRUE)
+    # update major version in otpcon
+    otpcon$version <- req$serverVersion$major
+    message(make_url(otpcon)$otp, " is running OTPv", otpcon$version)
+  }
+
+  # Confirm router is queryable
+  if (check_router(otpcon) == 200) {
+    message("Router ", make_url(otpcon)$router, " exists")
     return(otpcon)
+  } else {
+    stop("Router ", make_url(otpcon)$router,  " does not exist")
   }
 }
 
-# otpconnect class method to generate baseurl
+
+# otpconnect class method to generate router url
 
 make_url <- function(x)
 {
@@ -97,17 +116,18 @@ make_url.default <- function(x)
 
 make_url.otpconnect <- function(x)
 {
-  url <- paste0(
-    ifelse(isTRUE(x$ssl), 'https://', 'http://'),
-    x$hostname,
-    ':',
-    x$port,
-    '/otp/routers/',
-    x$router
-  )
-  return(url)
+  otp_url <- paste0(ifelse(isTRUE(x$ssl), 'https://', 'http://'),
+                    x$hostname,
+                    ':',
+                    x$port,
+                    '/otp')
+  router_url <- paste0(otp_url,
+                       '/routers/',
+                       x$router)
+  return(list(otp = otp_url, router = router_url))
 }
 
+
 # otpconnect method to check if router exists
 
 check_router <- function(x)
@@ -127,10 +147,10 @@ check_router.default <- function(x)
 
 check_router.otpconnect <- function(x)
 {
-  check <- try(httr::GET(make_url(x)), silent = T)
-  if(class(check) == "try-error"){
+  check <- try(httr::GET(make_url(x)$router), silent = T)
+  if (class(check) == "try-error") {
     return(check[1])
-  }else{
+  } else{
     return(check$status_code)
   }
 
